@@ -56,9 +56,9 @@ class SiriGrammar(Grammar):
     k_as = Keyword('as')
     k_backup_mode = Keyword('backup_mode')
     k_before = Keyword('before')
-    k_buffer_size = Keyword('buffer_size')
-    k_buffer_path = Keyword('buffer_path')
     k_between = Keyword('between')
+    k_buffer_path = Keyword('buffer_path')
+    k_buffer_size = Keyword('buffer_size')
     k_count = Keyword('count')
     k_create = Keyword('create')
     k_critical = Keyword('critical')
@@ -88,6 +88,7 @@ class SiriGrammar(Grammar):
     k_grant = Keyword('grant')
     k_group = Keyword('group')
     k_groups = Keyword('groups')
+    k_head = Keyword('head')
     k_help = Choice(Keyword('help'), Token('?'))
     k_idle_percentage = Keyword('idle_percentage')
     k_idle_time = Keyword('idle_time')
@@ -165,7 +166,8 @@ class SiriGrammar(Grammar):
     k_sync_progress = Keyword('sync_progress')
     k_tag = Keyword('tag')
     k_tags = Keyword('tags')
-    k_tee_pipe_name = Keyword('tee_pipe_name')
+    k_tail = Keyword('tail')
+    k_tee = Keyword('tee')
     k_time_precision = Keyword('time_precision')
     k_timeit = Keyword('timeit')
     k_timeval = Keyword('timeval')
@@ -287,7 +289,6 @@ class SiriGrammar(Grammar):
         k_reindex_progress,
         k_selected_points,
         k_sync_progress,
-        k_tee_pipe_name,
         k_uptime,
         most_greedy=False), ',', 1)
 
@@ -394,7 +395,6 @@ class SiriGrammar(Grammar):
             k_status,
             k_reindex_progress,
             k_sync_progress,
-            k_tee_pipe_name,
             most_greedy=False), str_operator, string),
         Sequence(k_online, bool_operator, _boolean),
         Sequence(k_log_level, int_operator, log_keywords),
@@ -467,6 +467,8 @@ class SiriGrammar(Grammar):
     before_expr = Sequence(k_before, time_expr)
     after_expr = Sequence(k_after, time_expr)
     between_expr = Sequence(k_between, time_expr, k_and, time_expr)
+    head_expr = Sequence(k_head, int_expr)
+    tail_expr = Sequence(k_tail, int_expr)
     access_expr = List(access_keywords, ',', 1)
 
     prefix_expr = Sequence(k_prefix, string)
@@ -606,7 +608,7 @@ class SiriGrammar(Grammar):
         Optional(Sequence(k_using, aggregate_functions)))
 
     set_address = Sequence(k_set, k_address, string)
-    set_tee_pipe_name = Sequence(k_set, k_tee_pipe_name, Choice(
+    set_tee = Sequence(k_set, k_tee, Choice(
         k_false,
         string,
         most_greedy=False))
@@ -642,6 +644,7 @@ class SiriGrammar(Grammar):
         set_timezone,
         set_expiration_num,
         set_expiration_log,
+        set_tee,
         most_greedy=False))
 
     alter_group = Sequence(k_group, group_name, Choice(
@@ -656,14 +659,12 @@ class SiriGrammar(Grammar):
     alter_server = Sequence(k_server, uuid, Choice(
         set_log_level,
         set_backup_mode,
-        set_tee_pipe_name,
         set_address,
         set_port,
         most_greedy=False))
 
     alter_servers = Sequence(k_servers, Optional(where_server), Choice(
         set_log_level,
-        set_tee_pipe_name,
         most_greedy=False))
 
     alter_user = Sequence(k_user, string, Choice(
@@ -819,6 +820,8 @@ class SiriGrammar(Grammar):
             after_expr,
             between_expr,
             before_expr,
+            tail_expr,
+            head_expr,
             most_greedy=False)),
         Optional(merge_as))
 
@@ -853,7 +856,7 @@ class SiriGrammar(Grammar):
         k_startup_time,
         k_status,
         k_sync_progress,
-        k_tee_pipe_name,
+        k_tee,
         k_time_precision,
         k_timezone,
         k_uptime,
