@@ -5,7 +5,7 @@
  * should be used with the libcleri module.
  *
  * Source class: SiriGrammar
- * Created at: 2020-09-25 10:57:26
+ * Created at: 2022-05-05 15:08:05
  */
 #ifndef CLERI_EXPORT_SIRI_GRAMMAR_GRAMMAR_H_
 #define CLERI_EXPORT_SIRI_GRAMMAR_GRAMMAR_H_
@@ -81,6 +81,7 @@ enum cleri_grammar_ids {
     CLERI_GID_GROUP_COLUMNS,
     CLERI_GID_GROUP_NAME,
     CLERI_GID_GROUP_TAG_MATCH,
+    CLERI_GID_HEAD_EXPR,
     CLERI_GID_HELP_ACCESS,
     CLERI_GID_HELP_ALTER,
     CLERI_GID_HELP_ALTER_DATABASE,
@@ -165,6 +166,7 @@ enum cleri_grammar_ids {
     CLERI_GID_K_GRANT,
     CLERI_GID_K_GROUP,
     CLERI_GID_K_GROUPS,
+    CLERI_GID_K_HEAD,
     CLERI_GID_K_HELP,
     CLERI_GID_K_IDLE_PERCENTAGE,
     CLERI_GID_K_IDLE_TIME,
@@ -236,7 +238,8 @@ enum cleri_grammar_ids {
     CLERI_GID_K_SYNC_PROGRESS,
     CLERI_GID_K_TAG,
     CLERI_GID_K_TAGS,
-    CLERI_GID_K_TEE_PIPE_NAME,
+    CLERI_GID_K_TAIL,
+    CLERI_GID_K_TEE,
     CLERI_GID_K_TIMEIT,
     CLERI_GID_K_TIMEVAL,
     CLERI_GID_K_TIMEZONE,
@@ -307,7 +310,7 @@ enum cleri_grammar_ids {
     CLERI_GID_SET_PASSWORD,
     CLERI_GID_SET_PORT,
     CLERI_GID_SET_SELECT_POINTS_LIMIT,
-    CLERI_GID_SET_TEE_PIPE_NAME,
+    CLERI_GID_SET_TEE,
     CLERI_GID_SET_TIMEZONE,
     CLERI_GID_SHARD_COLUMNS,
     CLERI_GID_SHOW_STMT,
@@ -318,6 +321,7 @@ enum cleri_grammar_ids {
     CLERI_GID_TAG_COLUMNS,
     CLERI_GID_TAG_NAME,
     CLERI_GID_TAG_SERIES,
+    CLERI_GID_TAIL_EXPR,
     CLERI_GID_TIMEIT_STMT,
     CLERI_GID_TIME_EXPR,
     CLERI_GID_UNTAG_SERIES,
