@@ -87,7 +87,7 @@
  *
  * Max 65535 since uint16_t is used to store this value
  */
-#define DEFAULT_MAX_CHUNK_SZ_NUM 800
+#define DEFAULT_MAX_CHUNK_SZ_NUM 1200
 #define DEFAULT_MAX_CHUNK_SZ_LOG 128
 
 static const siridb_shard_flags_repr_t flags_map[SHARD_STATUS_SIZE] = {
@@ -168,11 +168,6 @@ uint64_t siridb_shard_duration_from_interval(siridb_t * siridb, uint64_t interva
     return (x + 1) * hour;
 }
 
-uint64_t siridb_shard_interval_from_duration(uint64_t duration)
-{
-    return duration / OPTIMAL_POINTS_PER_SHARD;;
-}
-
 int siridb_shard_migrate(
         siridb_t * siridb,
         uint64_t shard_id,
@@ -462,10 +457,35 @@ siridb_shard_t *  siridb_shard_create(
     shard->replacing = replacing;
     shard->len = shard->size = HEADER_SIZE;
     shard->duration = duration;
-    shard->max_chunk_sz = (replacing == NULL) ?
-            (tp == SIRIDB_SHARD_TP_NUMBER ?
-                    DEFAULT_MAX_CHUNK_SZ_NUM : DEFAULT_MAX_CHUNK_SZ_LOG) :
-                    replacing->max_chunk_sz;
+    if (replacing == NULL)
+    {
+        shard->max_chunk_sz = (tp == SIRIDB_SHARD_TP_NUMBER)
+                ? DEFAULT_MAX_CHUNK_SZ_NUM
+                : DEFAULT_MAX_CHUNK_SZ_LOG;
+    }
+    else
+    {
+        shard->max_chunk_sz = replacing->max_chunk_sz;
+        if (tp == SIRIDB_SHARD_TP_NUMBER && shard->max_chunk_sz < 2000)
+        {
+            uint64_t now_ts;
+            struct timespec now;
+            clock_gettime(CLOCK_REALTIME, &now);
+            now_ts = siridb_time_now(siridb, now);
+
+            if (now_ts > id && (now_ts - id) > (duration * 4))
+            {
+                /* for numbers, we grow the max_chunk_size on each optimize;
+                 * as soon as the shard is older than 4 times the duration;
+                 * usually this happens only once, as afterwards, the max
+                 * chunk-size exceeds 2000 points; */
+                shard->max_chunk_sz <<= 2;  /* 1200 * 4 = 4800 */
+                log_debug(
+                        "Grow chunk size for shard id %" PRIu64 " to %u",
+                        id, shard->max_chunk_sz);
+            }
+        }
+    }
 
     if (SHARD_init_fn(siridb, shard) < 0)
     {
