@@ -5,7 +5,7 @@
  * should be used with the libcleri module.
  *
  * Source class: SiriGrammar
- * Created at: 2020-09-25 10:57:26
+ * Created at: 2022-05-05 15:08:05
  */
 
 #include "siri/grammar/grammar.h"
@@ -40,9 +40,9 @@ cleri_grammar_t * compile_siri_grammar_grammar(void)
     cleri_t * k_as = cleri_keyword(CLERI_GID_K_AS, "as", CLERI_CASE_SENSITIVE);
     cleri_t * k_backup_mode = cleri_keyword(CLERI_GID_K_BACKUP_MODE, "backup_mode", CLERI_CASE_SENSITIVE);
     cleri_t * k_before = cleri_keyword(CLERI_GID_K_BEFORE, "before", CLERI_CASE_SENSITIVE);
-    cleri_t * k_buffer_size = cleri_keyword(CLERI_GID_K_BUFFER_SIZE, "buffer_size", CLERI_CASE_SENSITIVE);
-    cleri_t * k_buffer_path = cleri_keyword(CLERI_GID_K_BUFFER_PATH, "buffer_path", CLERI_CASE_SENSITIVE);
     cleri_t * k_between = cleri_keyword(CLERI_GID_K_BETWEEN, "between", CLERI_CASE_SENSITIVE);
+    cleri_t * k_buffer_path = cleri_keyword(CLERI_GID_K_BUFFER_PATH, "buffer_path", CLERI_CASE_SENSITIVE);
+    cleri_t * k_buffer_size = cleri_keyword(CLERI_GID_K_BUFFER_SIZE, "buffer_size", CLERI_CASE_SENSITIVE);
     cleri_t * k_count = cleri_keyword(CLERI_GID_K_COUNT, "count", CLERI_CASE_SENSITIVE);
     cleri_t * k_create = cleri_keyword(CLERI_GID_K_CREATE, "create", CLERI_CASE_SENSITIVE);
     cleri_t * k_critical = cleri_keyword(CLERI_GID_K_CRITICAL, "critical", CLERI_CASE_SENSITIVE);
@@ -72,6 +72,7 @@ cleri_grammar_t * compile_siri_grammar_grammar(void)
     cleri_t * k_grant = cleri_keyword(CLERI_GID_K_GRANT, "grant", CLERI_CASE_SENSITIVE);
     cleri_t * k_group = cleri_keyword(CLERI_GID_K_GROUP, "group", CLERI_CASE_SENSITIVE);
     cleri_t * k_groups = cleri_keyword(CLERI_GID_K_GROUPS, "groups", CLERI_CASE_SENSITIVE);
+    cleri_t * k_head = cleri_keyword(CLERI_GID_K_HEAD, "head", CLERI_CASE_SENSITIVE);
     cleri_t * k_help = cleri_choice(
         CLERI_GID_K_HELP,
         CLERI_MOST_GREEDY,
@@ -166,7 +167,8 @@ cleri_grammar_t * compile_siri_grammar_grammar(void)
     cleri_t * k_sync_progress = cleri_keyword(CLERI_GID_K_SYNC_PROGRESS, "sync_progress", CLERI_CASE_SENSITIVE);
     cleri_t * k_tag = cleri_keyword(CLERI_GID_K_TAG, "tag", CLERI_CASE_SENSITIVE);
     cleri_t * k_tags = cleri_keyword(CLERI_GID_K_TAGS, "tags", CLERI_CASE_SENSITIVE);
-    cleri_t * k_tee_pipe_name = cleri_keyword(CLERI_GID_K_TEE_PIPE_NAME, "tee_pipe_name", CLERI_CASE_SENSITIVE);
+    cleri_t * k_tail = cleri_keyword(CLERI_GID_K_TAIL, "tail", CLERI_CASE_SENSITIVE);
+    cleri_t * k_tee = cleri_keyword(CLERI_GID_K_TEE, "tee", CLERI_CASE_SENSITIVE);
     cleri_t * k_time_precision = cleri_keyword(CLERI_GID_K_TIME_PRECISION, "time_precision", CLERI_CASE_SENSITIVE);
     cleri_t * k_timeit = cleri_keyword(CLERI_GID_K_TIMEIT, "timeit", CLERI_CASE_SENSITIVE);
     cleri_t * k_timeval = cleri_keyword(CLERI_GID_K_TIMEVAL, "timeval", CLERI_CASE_SENSITIVE);
@@ -312,7 +314,7 @@ cleri_grammar_t * compile_siri_grammar_grammar(void)
     cleri_t * server_columns = cleri_list(CLERI_GID_SERVER_COLUMNS, cleri_choice(
         CLERI_NONE,
         CLERI_FIRST_MATCH,
-        29,
+        28,
         k_address,
         k_buffer_path,
         k_buffer_size,
@@ -340,7 +342,6 @@ cleri_grammar_t * compile_siri_grammar_grammar(void)
         k_reindex_progress,
         k_selected_points,
         k_sync_progress,
-        k_tee_pipe_name,
         k_uptime
     ), cleri_token(CLERI_NONE, ","), 1, 0, 0);
     cleri_t * group_columns = cleri_list(CLERI_GID_GROUP_COLUMNS, cleri_choice(
@@ -625,7 +626,7 @@ cleri_grammar_t * compile_siri_grammar_grammar(void)
                 cleri_choice(
                     CLERI_NONE,
                     CLERI_FIRST_MATCH,
-                    12,
+                    11,
                     k_address,
                     k_buffer_path,
                     k_dbpath,
@@ -636,8 +637,7 @@ cleri_grammar_t * compile_siri_grammar_grammar(void)
                     k_version,
                     k_status,
                     k_reindex_progress,
-                    k_sync_progress,
-                    k_tee_pipe_name
+                    k_sync_progress
                 ),
                 str_operator,
                 string
@@ -897,6 +897,18 @@ cleri_grammar_t * compile_siri_grammar_grammar(void)
         k_and,
         time_expr
     );
+    cleri_t * head_expr = cleri_sequence(
+        CLERI_GID_HEAD_EXPR,
+        2,
+        k_head,
+        int_expr
+    );
+    cleri_t * tail_expr = cleri_sequence(
+        CLERI_GID_TAIL_EXPR,
+        2,
+        k_tail,
+        int_expr
+    );
     cleri_t * access_expr = cleri_list(CLERI_GID_ACCESS_EXPR, access_keywords, cleri_token(CLERI_NONE, ","), 1, 0, 0);
     cleri_t * prefix_expr = cleri_sequence(
         CLERI_GID_PREFIX_EXPR,
@@ -1153,11 +1165,11 @@ cleri_grammar_t * compile_siri_grammar_grammar(void)
         k_address,
         string
     );
-    cleri_t * set_tee_pipe_name = cleri_sequence(
-        CLERI_GID_SET_TEE_PIPE_NAME,
+    cleri_t * set_tee = cleri_sequence(
+        CLERI_GID_SET_TEE,
         3,
         k_set,
-        k_tee_pipe_name,
+        k_tee,
         cleri_choice(
             CLERI_NONE,
             CLERI_FIRST_MATCH,
@@ -1278,13 +1290,14 @@ cleri_grammar_t * compile_siri_grammar_grammar(void)
         cleri_choice(
             CLERI_NONE,
             CLERI_FIRST_MATCH,
-            6,
+            7,
             set_drop_threshold,
             set_list_limit,
             set_select_points_limit,
             set_timezone,
             set_expiration_num,
-            set_expiration_log
+            set_expiration_log,
+            set_tee
         )
     );
     cleri_t * alter_group = cleri_sequence(
@@ -1320,10 +1333,9 @@ cleri_grammar_t * compile_siri_grammar_grammar(void)
         cleri_choice(
             CLERI_NONE,
             CLERI_FIRST_MATCH,
-            5,
+            4,
             set_log_level,
             set_backup_mode,
-            set_tee_pipe_name,
             set_address,
             set_port
         )
@@ -1336,9 +1348,8 @@ cleri_grammar_t * compile_siri_grammar_grammar(void)
         cleri_choice(
             CLERI_NONE,
             CLERI_FIRST_MATCH,
-            2,
-            set_log_level,
-            set_tee_pipe_name
+            1,
+            set_log_level
         )
     );
     cleri_t * alter_user = cleri_sequence(
@@ -1679,10 +1690,12 @@ cleri_grammar_t * compile_siri_grammar_grammar(void)
         cleri_optional(CLERI_NONE, cleri_choice(
             CLERI_NONE,
             CLERI_FIRST_MATCH,
-            3,
+            5,
             after_expr,
             between_expr,
-            before_expr
+            before_expr,
+            tail_expr,
+            head_expr
         )),
         cleri_optional(CLERI_NONE, merge_as)
     );
@@ -1724,7 +1737,7 @@ cleri_grammar_t * compile_siri_grammar_grammar(void)
             k_startup_time,
             k_status,
             k_sync_progress,
-            k_tee_pipe_name,
+            k_tee,
             k_time_precision,
             k_timezone,
             k_uptime,
